@@ -1,5 +1,5 @@
-# Gufw 19.04.0 - http://gufw.org
-# Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
+# Gufw - https://costales.github.io/projects/gufw/
+# Copyright (C) 2008-2025 Marcos Alvarez Costales https://costales.github.io
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,8 +18,8 @@
 import gi
 gi.require_version('Gtk', '3.0')
 gi.require_version('Gdk', '3.0')
-gi.require_version('WebKit2', '4.0')
-from gi.repository import Gtk, Gdk, WebKit2
+from gi.repository import Gtk, Gdk
+Gdk.init([])
 from string import Template
 
 import os, re, sys, subprocess, platform
@@ -70,7 +70,7 @@ class Gufw:
                    2: 'log-all'}
 
     def __init__(self, frontend):
-        self.fw = frontend
+        self.frontend = frontend
         
         self.builder = Gtk.Builder()
         self.builder.set_translation_domain('gufw')
@@ -87,14 +87,15 @@ class Gufw:
     def _set_objects_name(self):
         self.winMain = self.builder.get_object('main')
         
-        self.profile      = self.builder.get_object('profile')
-        self.switchStatus = self.builder.get_object('switchStatus')
-        self.incoming     = self.builder.get_object('incoming')
-        self.outgoing     = self.builder.get_object('outgoing')
-        self.routed_lbl   = self.builder.get_object('routed_lbl')
-        self.box_routed   = self.builder.get_object('box_routed')
-        self.routed       = self.builder.get_object('routed')
-        self.shield       = self.builder.get_object('shield')
+        self.profile       = self.builder.get_object('profile')
+        self.profile_label = self.builder.get_object('label_profile')
+        self.switchStatus  = self.builder.get_object('switchStatus')
+        self.incoming      = self.builder.get_object('incoming')
+        self.outgoing      = self.builder.get_object('outgoing')
+        self.routed_lbl    = self.builder.get_object('routed_lbl')
+        self.box_routed    = self.builder.get_object('box_routed')
+        self.routed        = self.builder.get_object('routed')
+        self.shield        = self.builder.get_object('shield')
         
         self.rules_box       = self.builder.get_object('boxRules')
         self.rules           = self.builder.get_object('Rules')
@@ -113,21 +114,9 @@ class Gufw:
         self.log_copy     = self.builder.get_object('btnLogCopy')
         self.log_delete   = self.builder.get_object('btnLogCopy')
         
-        self.web = self.builder.get_object('boxWeb')
-        self.web_content = WebKit2.WebView()
-        self.web_content.connect('context-menu', self.context_menu_cb)
+        self.menu_file_import = self.builder.get_object('menu_import')
+        self.menu_file_export = self.builder.get_object('menu_export')
 
-        settings = self.web_content.get_settings()
-        self.web_content.set_settings(settings)
-        self.web.add(self.web_content)
-        # For ORCA
-        self.tuto_label = Gtk.Label()
-        self.tuto_label.set_text(_("Getting started"))
-        self.tuto_label.set_mnemonic_widget(self.web)
-        
-        settings = self.web_content.get_settings()
-        settings.set_property('enable-caret-browsing', True)
-        
         self.statusbar = self.builder.get_object('statusmsg')
         self.progress  = self.builder.get_object('progress')
         
@@ -153,11 +142,11 @@ class Gufw:
         
         # Listening report
         self.listening_model = Gtk.ListStore(str, # 0  protocol
-                                              str, # 1 port
-                                              str, # 2 address
-                                              str, # 3 app
-                                              str, # 4 color
-                                              int) # 5 number
+                                             int, # 1 port
+                                             str, # 2 address
+                                             str, # 3 app
+                                             str, # 4 color
+                                             int) # 5 number
         self.tv_report = self.report
         self.tv_report.set_model(self.listening_model)
         self.tv_report.get_selection().set_mode(Gtk.SelectionMode.SINGLE)
@@ -176,23 +165,17 @@ class Gufw:
         stack = Gtk.Stack()
         stack.set_transition_type(Gtk.StackTransitionType.SLIDE_LEFT_RIGHT)
         stack.set_transition_duration(700)
-        # Stack 1 = Tutorial
-        vbox_home = Gtk.Box()
-        self.viewport_home  = self.builder.get_object('viewport_home')
-        self.viewport_home.reparent(vbox_home)
-        stack.add_titled(vbox_home, "tutorial", _("Getting started"))
-        stack.child_set_property(vbox_home, "icon-name", "go-home") # Set icon
-        # Stack 2 = Rules
+        # Stack 1 = Rules
         vbox_rules = Gtk.Box()
         self.viewport_rules  = self.builder.get_object('viewport_rules')
         self.viewport_rules.reparent(vbox_rules)
         stack.add_titled(vbox_rules, "rules", _("Rules"))
-        # Stack 3 = Report
+        # Stack 2 = Report
         vbox_report = Gtk.Box()
         self.viewport_report  = self.builder.get_object('viewport_report')
         self.viewport_report.reparent(vbox_report)
         stack.add_titled(vbox_report, "report", _("Report"))
-        # Stack 4 = Log
+        # Stack 3 = Log
         vbox_log = Gtk.Box()
         self.viewport_log  = self.builder.get_object('viewport_log')
         self.viewport_log.reparent(vbox_log)
@@ -214,22 +197,22 @@ class Gufw:
         self.stack_vbox.pack_end(stack, True, True, 0)
     
     def _set_initial_values(self):
-        for profile in self.fw.get_all_profiles():
+        for profile in self.frontend.get_all_profiles():
             self.profile.append_text(profile)
-        self.profile.set_active(self.fw.get_all_profiles().index(self.fw.get_profile()))
+        self.profile.set_active(self.frontend.get_all_profiles().index(self.frontend.get_profile()))
         
-        self.switchStatus.set_active(self.fw.get_status())
+        self.switchStatus.set_active(self.frontend.get_status())
         
-        self.incoming.set_active(self.POLICY2NUM[self.fw.get_policy('incoming')])
-        self.outgoing.set_active(self.POLICY2NUM[self.fw.get_policy('outgoing')])
-        self.routed.set_active(self.POLICY2NUM[self.fw.get_policy('routed')])
-        self.incoming.set_sensitive(self.fw.get_status())
-        self.outgoing.set_sensitive(self.fw.get_status())
-        self.routed.set_sensitive(self.fw.get_status())
-        self.show_add_btn.set_sensitive(self.fw.get_status())
-        self.detele_rule_btn.set_sensitive(self.fw.get_status())
-        self.edit_rule_btn.set_sensitive(self.fw.get_status())
-        self.report_rule_btn.set_sensitive(self.fw.get_status())
+        self.incoming.set_active(self.POLICY2NUM[self.frontend.get_policy('incoming')])
+        self.outgoing.set_active(self.POLICY2NUM[self.frontend.get_policy('outgoing')])
+        self.routed.set_active(self.POLICY2NUM[self.frontend.get_policy('routed')])
+        self.incoming.set_sensitive(self.frontend.get_status())
+        self.outgoing.set_sensitive(self.frontend.get_status())
+        self.routed.set_sensitive(self.frontend.get_status())
+        self.show_add_btn.set_sensitive(self.frontend.get_status())
+        self.detele_rule_btn.set_sensitive(self.frontend.get_status())
+        self.edit_rule_btn.set_sensitive(self.frontend.get_status())
+        self.report_rule_btn.set_sensitive(self.frontend.get_status())
         
         render_txt = Gtk.CellRendererText()
         
@@ -282,21 +265,24 @@ class Gufw:
         
         self.listening = ListeningReport(self)
         
-        self.add_to_log(self.fw.get_log(), self.GRAY, False)
-        
-        self._load_tutorial()
+        self.add_to_log(self.frontend.get_log(), self.GRAY, False)
         
         self._set_shield()
         
         self._restore_window_size(self.winMain)
         self.winMain.show_all()
         
-        if self.fw.get_policy('routed') == 'disabled':
+        if self.frontend.get_policy('routed') == 'disabled':
             self.routed_lbl.set_visible(False)
             self.box_routed.set_visible(False)
-        
-        if self.fw.get_status():
-            self.print_rules(self.fw.get_rules())
+
+        if self.frontend.get_config_value('ShowProfiles') != 'yes':
+            self.profile.hide()
+            self.profile_label.hide()
+            self.menu_file_import.hide()
+            self.menu_file_export.hide()
+
+        self.print_rules(self.frontend.get_rules(False))
         
         self.btn_report_play.hide()
 
@@ -304,57 +290,6 @@ class Gufw:
     def context_menu_cb(webview, context_menu, event, hit_test_result, error):
         return True
 
-    def _load_tutorial(self):
-        f = open('/usr/share/gufw/media/tutorial/index.html', 'r')
-        html_content = f.read()
-        f.close()
-        
-        replace_html = dict(heading1=_("Getting started"),
-                            intro=_("An uncomplicated way to manage your firewall, powered by ufw. Easy, simple, nice and useful! :)"),
-                            heading2=_("Basic"),
-                            heading3=_("FAQ"),
-                            best_conf=_("If you are a normal user, you will be safe with this setting (Status=On, Incoming=Deny, Outgoing=Allow). Remember to append allow rules for your P2P apps:"),
-                            rename_profile=_("You can rename your profiles with just 2 clicks on them:"),
-                            rule_name=_("The Rule Name will help you to identify your rules in the future:"),
-                            faq1_q=_("How to autostart Gufw with the system?"),
-                            faq1_a=_("You do not need it. After you do all of the changes in Gufw, the settings are still in place until the next changes."),
-                            faq2_q=_("Why is Gufw disabled by default?"),
-                            faq2_a=_("By default, the firewall does not open ports to the outside world."),
-                            faq3_q=_("Some rules are added by themselves?"),
-                            faq3_a=_("Well, the behaviour is such that when you change or import a profile, or when you edit a rule, Gufw will add that rule again, then ufw re-adds that rule for IPv4 and IPv6."),
-                            faq4_q=_("What is Allow, Deny, Reject and Limit?"),
-                            faq4_a1=_("Allow: Will allow traffic."),
-                            faq4_a2=_("Deny: Will deny traffic."),
-                            faq4_a3=_("Reject: Will deny traffic and will inform that it has been rejected."),
-                            faq4_a4=_("Limit: Will deny traffic if an IP tried several connections."),
-                            faq5_q=_("I see some rules in all profiles"),
-                            faq5_a=_("All the ufw rules will be appear in all profiles."),
-                            faq6_q=_("What do I see in the Listening Report?"),
-                            faq6_a=_("The ports on the live system in the listening state for TCP and the open state for UDP."),
-                            faq8_q=_("I want even more!"),
-                            faq8_a=_("You'll find more information in the community documentation :)"))
-        html = Template(html_content).safe_substitute(replace_html)
-        self.web_content.load_html(html, "file:///")
-    
-    def _show_web(self, url):
-        distro = platform.linux_distribution()[0].lower()
-        try:
-            user = sys.argv[1]
-        except Exception:
-            self.show_dialog(self.winMain, _("Visit this web (please, copy & paste in your browser):"), url)
-            return
-        
-        if distro != 'ubuntu' and distro != 'linuxmint' and distro != 'debian':
-            self.show_dialog(self.winMain, _("Visit this web (please, copy & paste in your browser):"), url)
-            return
-        if user == 'root' or user == '-ssh' or not user:
-            self.show_dialog(self.winMain, _("Visit this web (please, copy & paste in your browser):"), url)
-            return
-        
-        # Launching browser
-        cmd = "su -c 'python -m webbrowser -t \"" + url + "\"' - " + user
-        subprocess.Popen(cmd, shell=True)
-    
     def on_menu_import_activate(self, widget, data=None):
         import_profile = self._file_dialog('open', _("Import Profile"))
         
@@ -373,11 +308,11 @@ class Gufw:
             self.show_dialog(self.winMain, _("Error"), _("Filename has not valid characters. Rename the file\nto only letters, numbers, dashes and underscores"))
             return
         
-        if profile in self.fw.get_all_profiles():
+        if profile in self.frontend.get_all_profiles():
             self.set_statusbar_msg(_("Operation cancelled"))
             self.show_dialog(self.winMain, _("Profile already exists"), _("Delete it before from the Preferences Window or rename the file (the profile will be the filename)"))
         else:
-            self.fw.import_profile(import_profile)
+            self.frontend.import_profile(import_profile)
             self.profile.append_text(profile)
             self.add_to_log(_("Profile imported: ") + import_profile)
             self.set_statusbar_msg(_("Profile imported, now you can choose it in the profiles"))
@@ -392,7 +327,7 @@ class Gufw:
         if export_profile[-8:] != '.profile':
             export_profile = export_profile + '.profile'
         
-        self.fw.export_profile(export_profile)
+        self.frontend.export_profile(export_profile)
         self.add_to_log(_("Profile exported: ") + export_profile)
         self.set_statusbar_msg(_("Profile exported"))
     
@@ -408,10 +343,10 @@ class Gufw:
         Gtk.main_quit()
     
     def _set_shield(self):
-        if self.fw.get_status():
-            file_shield = os.path.join('/usr/share/gufw/media/shields/', self.fw.get_policy('incoming').lower() + '_' + self.fw.get_policy('outgoing').lower() + '_' + self.fw.get_policy('routed').lower() + '.png')
+        if self.frontend.get_status():
+            file_shield = os.path.join('/usr/share/gufw/media/shields/', self.frontend.get_policy('incoming').lower() + '_' + self.frontend.get_policy('outgoing').lower() + '_' + self.frontend.get_policy('routed').lower() + '.png')
         else:
-            if self.fw.get_policy('routed') == 'disabled':
+            if self.frontend.get_policy('routed') == 'disabled':
                 file_shield = os.path.join('/usr/share/gufw/media/shields/', 'disabled_disabled_disabled.png')
             else:
                 file_shield = os.path.join('/usr/share/gufw/media/shields/', 'disabled_disabled_enabled.png')
@@ -420,85 +355,55 @@ class Gufw:
     def on_menu_reset_activate(self, widget, data=None):
         answer = self._show_question(self.winMain, _("Reset Firewall"), _("This will remove all rules in the current\nprofile and disable the firewall"), _("Do you want to continue?"))
         if answer:
-            if self.fw.get_status():
+            if self.frontend.get_status():
                 self.switchStatus.set_active(False)
-            self.fw.reset()
+            self.frontend.reset()
             self.add_to_log(_("Removed rules and reset firewall!"))
     
     def on_btnLogRemove_clicked(self, widget, data=None):
-        self.fw.refresh_log()
+        self.frontend.refresh_log()
         self.log_txt.set_text('')
         self.add_to_log(_("Gufw Log: Removed"))
         self.set_statusbar_msg(_("Gufw Log removed"))
     
     def on_btnLogCopy_clicked(self, widget, data=None):
         self.clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
-        self.clipboard.set_text(self.fw.get_log(), -1)
+        self.clipboard.set_text(self.frontend.get_log(), -1)
         self.set_statusbar_msg(_("Text copied to clipboard"))
     
-    def on_donate_btn_clicked(self, widget, data=None):
-        self._show_web('http://gufw.org/donate')
-    
     def on_menu_about_activate(self, widget, data=None):
         aboutwin = About(self)
     
-    def on_menu_doc_activate(self, widget, data=None):
-        self._show_web('http://help.ubuntu.com/community/Gufw')
-    
-    def on_menu_answers_activate(self, widget, data=None):
-        self._show_web('http://answers.launchpad.net/gui-ufw')
-    
-    def on_menu_bugs_activate(self, widget, data=None):
-        self._show_web('http://bugs.launchpad.net/gui-ufw')
-    
-    def on_menu_translations_activate(self, widget, data=None):
-        self._show_web('https://translations.launchpad.net/gui-ufw')
-    
-    def on_menu_donate_activate(self, widget, data=None):
-        self._show_web('http://gufw.org/donate')
-    
-    def on_menu_gplus_activate(self, widget, data=None):
-        self._show_web('http://plus.google.com/b/104342291112771981280/')
-    
-    def on_menu_gplus_community_activate(self, widget, data=None):
-        self._show_web('http://plus.google.com/communities/104067858618275933076')
-    
-    def on_menu_twitter_activate(self, widget, data=None):
-        self._show_web('http://twitter.com/gufw')
-    
-    def on_menu_identica_activate(self, widget, data=None):
-        self._show_web('http://identi.ca/gufw')
-    
     def on_menu_preferences_activate(self, widget, data=None):
         preferenceswin = Preferences(self)
     
     def on_incoming_changed(self, widget, data=None):
-        self.fw.set_policy('incoming', self.NUM2POLICY[self.incoming.get_active()].lower())
+        self.frontend.set_policy('incoming', self.NUM2POLICY[self.incoming.get_active()].lower())
         self._set_shield()
         # Translators: Policy
-        self.add_to_log(_("Incoming: ") + self.incoming.get_active_text(), self.POLICY2COLOR[self.fw.get_policy('incoming')])
+        self.add_to_log(_("Incoming: ") + self.incoming.get_active_text(), self.POLICY2COLOR[self.frontend.get_policy('incoming')])
         self.set_statusbar_msg(_("Incoming policy changed"))
-        if self.fw.get_policy('incoming') != self.NUM2POLICY[self.incoming.get_active()].lower():
+        if self.frontend.get_policy('incoming') != self.NUM2POLICY[self.incoming.get_active()].lower():
             self.show_dialog(self.winMain, _("There was an error changing the incoming policy"), _("Restart your firewall to refresh to the real status\nand please report this bug"))
     
     def on_outgoing_changed(self, widget, data=None):
-        self.fw.set_policy('outgoing', self.NUM2POLICY[self.outgoing.get_active()].lower())
+        self.frontend.set_policy('outgoing', self.NUM2POLICY[self.outgoing.get_active()].lower())
         self._set_shield()
-        self.add_to_log(_("Outgoing: ") + self.outgoing.get_active_text(), self.POLICY2COLOR[self.fw.get_policy('outgoing')])
+        self.add_to_log(_("Outgoing: ") + self.outgoing.get_active_text(), self.POLICY2COLOR[self.frontend.get_policy('outgoing')])
         self.set_statusbar_msg(_("Outgoing policy changed"))
-        if self.fw.get_policy('outgoing') != self.NUM2POLICY[self.outgoing.get_active()].lower():
+        if self.frontend.get_policy('outgoing') != self.NUM2POLICY[self.outgoing.get_active()].lower():
             self.show_dialog(self.winMain, _("There was an error changing the outgoing policy"), _("Restart your firewall to refresh to the real status\nand please report this bug"))
     
     def on_routed_changed(self, widget, data=None):
         try: # Could be inconsistent between imports and changes of Routed status
-            self.fw.set_policy('routed', self.NUM2POLICY[self.routed.get_active()].lower())
+            self.frontend.set_policy('routed', self.NUM2POLICY[self.routed.get_active()].lower())
         except Exception:
             return
         self._set_shield()
         # Translators: Routed firewall changed
-        self.add_to_log(_("Routed: ") + self.routed.get_active_text(), self.POLICY2COLOR[self.fw.get_policy('routed')])
+        self.add_to_log(_("Routed: ") + self.routed.get_active_text(), self.POLICY2COLOR[self.frontend.get_policy('routed')])
         self.set_statusbar_msg(_("Routed policy changed"))
-        if self.fw.get_policy('routed') != self.NUM2POLICY[self.routed.get_active()].lower():
+        if self.frontend.get_policy('routed') != self.NUM2POLICY[self.routed.get_active()].lower():
             self.show_dialog(self.winMain, _("There was an error changing the routed policy"), _("Restart your firewall to refresh to the real status\nand please report this bug"))
     
     def on_btnAddRule_clicked(self, widget, data=None):
@@ -514,7 +419,7 @@ class Gufw:
         if len(rows) == 1:
             iter_row = self.listening_model.get_iter(rows[0],)
             protocol = self.listening_model.get_value(iter_row, 0)
-            port     = self.listening_model.get_value(iter_row, 1)
+            port     = str(self.listening_model.get_value(iter_row, 1))
             address  = self.listening_model.get_value(iter_row, 2)
             app      = self.listening_model.get_value(iter_row, 3)
             if address == '*':
@@ -540,10 +445,10 @@ class Gufw:
         self.listening.set_pause(False)
     
     def on_switchStatus_active_notify(self, widget, data=None):
-        self.fw.set_status(self.switchStatus.get_active())
-        self.print_rules(self.fw.get_rules())
+        self.frontend.set_status(self.switchStatus.get_active())
+        self.print_rules(self.frontend.get_rules(False))
         
-        if self.fw.get_status():
+        if self.frontend.get_status():
             # Translators: About firewall
             self.add_to_log(_("Status: Enabled"), self.GREEN)
             self.set_statusbar_msg(_("Firewall enabled"))
@@ -552,15 +457,15 @@ class Gufw:
             self.add_to_log(_("Status: Disabled"), self.RED)
             self.set_statusbar_msg(_("Firewall disabled"))
         
-        self.incoming.set_sensitive(self.fw.get_status())
-        self.outgoing.set_sensitive(self.fw.get_status())
-        self.routed.set_sensitive(self.fw.get_status())
-        self.show_add_btn.set_sensitive(self.fw.get_status())
-        self.detele_rule_btn.set_sensitive(self.fw.get_status())
-        self.edit_rule_btn.set_sensitive(self.fw.get_status())
-        self.report_rule_btn.set_sensitive(self.fw.get_status())
+        self.incoming.set_sensitive(self.frontend.get_status())
+        self.outgoing.set_sensitive(self.frontend.get_status())
+        self.routed.set_sensitive(self.frontend.get_status())
+        self.show_add_btn.set_sensitive(self.frontend.get_status())
+        self.detele_rule_btn.set_sensitive(self.frontend.get_status())
+        self.edit_rule_btn.set_sensitive(self.frontend.get_status())
+        self.report_rule_btn.set_sensitive(self.frontend.get_status())
         self._set_shield()
-        if self.fw.get_status() != self.switchStatus.get_active():
+        if self.frontend.get_status() != self.switchStatus.get_active():
             self.show_dialog(self.winMain, _("There was an error changing the firewall status"), _("Restart your firewall to refresh to the real status and please report this bug"))
 
     def on_btnDeleteRule_clicked(self, widget, data=None):
@@ -575,16 +480,16 @@ class Gufw:
         total_rules = sorted(total_rules, key=int, reverse=True)
         
         # Confirm?
-        if (self.fw.get_config_value('ConfirmDeteleRule') == 'yes') and (len(total_rules) > 0):
+        if (self.frontend.get_config_value('ConfirmDeteleRule') == 'yes') and (len(total_rules) > 0):
             answer = self._show_question(self.winMain, _("Delete rule"), _("You will delete all selected rules"), _("Do you want to continue?"))
             if not answer:
                 return
         
         for row in total_rules:
             rules_selected = True            
-            rules_before = self.fw.get_rules()
-            cmd = self.fw.delete_rule(row)
-            rules_after = self.fw.get_rules()
+            rules_before = self.frontend.get_rules()
+            cmd = self.frontend.delete_rule(row)
+            rules_after = self.frontend.get_rules()
             
             if len(rules_before) != len(rules_after):
                 self.add_to_log(cmd[0])
@@ -595,7 +500,7 @@ class Gufw:
                 self.set_statusbar_msg(_("Error. Review Gufw Log"))
         
         if rules_selected:
-            self.print_rules(self.fw.get_rules())
+            self.print_rules(self.frontend.get_rules())
         else:
             self.show_dialog(self.winMain, _("No rule selected"), _("You have to select a rule"))
     
@@ -639,15 +544,15 @@ class Gufw:
         updatewin = Update(self, ufw_row, description, cmd, policy, direction, proto, from_ip, from_port, to_ip, to_port, iface, routed, logging)
 
     def on_profile_changed(self, widget, data=None):
-        operation = self.fw.set_profile(self.profile.get_active_text())
+        operation = self.frontend.set_profile(self.profile.get_active_text())
         self.add_to_log(_("Changing profile: ") + self.profile.get_active_text())
         
-        self.incoming.set_active(self.POLICY2NUM[self.fw.get_policy('incoming')])
-        self.outgoing.set_active(self.POLICY2NUM[self.fw.get_policy('outgoing')])
-        self.routed.set_active(self.POLICY2NUM[self.fw.get_policy('routed')])
-        self.switchStatus.set_active(self.fw.get_status())
+        self.incoming.set_active(self.POLICY2NUM[self.frontend.get_policy('incoming')])
+        self.outgoing.set_active(self.POLICY2NUM[self.frontend.get_policy('outgoing')])
+        self.routed.set_active(self.POLICY2NUM[self.frontend.get_policy('routed')])
+        self.switchStatus.set_active(self.frontend.get_status())
         
-        self.print_rules(self.fw.get_rules())
+        self.print_rules(self.frontend.get_rules())
         
         for msg in operation:
             self.add_to_log(msg)
@@ -688,11 +593,11 @@ class Gufw:
         return self.txt_tag_black
             
     def add_to_log(self, msg, color=BLACK, force_save=True):
-        if not self.fw.get_logging():
+        if not self.frontend.get_logging():
             return
         
         if force_save:
-            new_line = self.fw.add_to_log(msg)
+            new_line = self.frontend.add_to_log(msg)
             self.log_txt.insert_with_tags(self.log_txt.get_start_iter(), new_line, self._get_log_color(color)) 
         else:
             self.log_txt.insert_with_tags(self.log_txt.get_end_iter(), msg, self._get_log_color(color)) 
@@ -703,7 +608,7 @@ class Gufw:
     
     def print_rules(self, rules):
         self.rules_model.clear()
-        if not self.fw.get_status():
+        if not self.frontend.get_status():
             return
         
         row = 1
@@ -801,10 +706,10 @@ class Gufw:
         
         width = 0
         height = 0
-        if self.fw.get_config_value('WindowWidth'):
-            width = int(self.fw.get_config_value('WindowWidth'))
-        if self.fw.get_config_value('WindowHeight'):
-            height = int(self.fw.get_config_value('WindowHeight'))
+        if self.frontend.get_config_value('WindowWidth'):
+            width = int(self.frontend.get_config_value('WindowWidth'))
+        if self.frontend.get_config_value('WindowHeight'):
+            height = int(self.frontend.get_config_value('WindowHeight'))
         
         if width >= Gdk.Screen.width() and height >= Gdk.Screen.height():
             win.maximize()
@@ -813,8 +718,8 @@ class Gufw:
             
     def _save_window_size(self, win):
         width, height = win.get_size()
-        self.fw.set_config_value('WindowWidth',  str(width))
-        self.fw.set_config_value('WindowHeight', str(height))
+        self.frontend.set_config_value('WindowWidth',  str(width))
+        self.frontend.set_config_value('WindowHeight', str(height))
     
     def validate_rule(self, win, from_ip, from_port, to_ip, to_port, insert='', routed=''):
         # At least 1 Port/IP
@@ -827,7 +732,7 @@ class Gufw:
             insert_into = 0
         else:
             insert_into = int(insert)
-        if insert_into > 0 and insert_into > self.fw.get_number_rules():
+        if insert_into > 0 and insert_into > self.frontend.get_number_rules():
             self.show_dialog(win, _("Insert number bigger that number of rules"), _("By example, if you have 3 rules, you can't insert a rule into position 4"))
             return False
         
